package com.qmth.themis.notify.config;

import com.qmth.themis.business.constant.SystemConstant;
import com.qmth.themis.business.entity.SysConfig;
import com.qmth.themis.business.service.ThemisCacheService;
import com.qmth.themis.common.exception.BusinessException;
import com.qmth.themis.notify.interceptor.AuthInterceptor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

import javax.annotation.Resource;
import java.util.Arrays;
import java.util.Optional;

/**
 * @Description: 路径拦截器
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2020/6/27
 */
@Configuration
public class WebMvcConfig implements WebMvcConfigurer {

    @Resource
    ThemisCacheService themisCacheService;

    @Bean
    public AuthInterceptor AuthInterceptor() {
        return new AuthInterceptor();
    }

    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        SysConfig sysConfig = themisCacheService.addSysConfigCache(SystemConstant.NOTIFY_NO_AUTH_URLS);
        Optional.ofNullable(sysConfig).orElseThrow(() -> new BusinessException("未配置notify无需鉴权的url"));

        registry.addInterceptor(AuthInterceptor()).addPathPatterns(SystemConstant.ALL_PATH)
                .excludePathPatterns(Arrays.asList(StringUtils.split(sysConfig.getConfigValue(), ",")));
    }
}